# -*- coding:utf-8 -*-
# Author: hankcs
# Date: 2020-08-11 20:35

_HOME = 'https://github.com/hankcs/multi-criteria-cws/archive/naive-mix.zip#data/raw/'

CNC_TRAIN_ALL = _HOME + 'cnc/train-all.txt'
CNC_TRAIN = _HOME + 'cnc/train.txt'
CNC_DEV = _HOME + 'cnc/dev.txt'
CNC_TEST = _HOME + 'cnc/test.txt'

CTB_TRAIN_ALL = _HOME + 'ctb/train-all.txt'
CTB_TRAIN = _HOME + 'ctb/train.txt'
CTB_DEV = _HOME + 'ctb/dev.txt'
CTB_TEST = _HOME + 'ctb/test.txt'

SXU_TRAIN_ALL = _HOME + 'sxu/train-all.txt'
SXU_TRAIN = _HOME + 'sxu/train.txt'
SXU_DEV = _HOME + 'sxu/dev.txt'
SXU_TEST = _HOME + 'sxu/test.txt'

UDC_TRAIN_ALL = _HOME + 'udc/train-all.txt'
UDC_TRAIN = _HOME + 'udc/train.txt'
UDC_DEV = _HOME + 'udc/dev.txt'
UDC_TEST = _HOME + 'udc/test.txt'

WTB_TRAIN_ALL = _HOME + 'wtb/train-all.txt'
WTB_TRAIN = _HOME + 'wtb/train.txt'
WTB_DEV = _HOME + 'wtb/dev.txt'
WTB_TEST = _HOME + 'wtb/test.txt'

ZX_TRAIN_ALL = _HOME + 'zx/train-all.txt'
ZX_TRAIN = _HOME + 'zx/train.txt'
ZX_DEV = _HOME + 'zx/dev.txt'
ZX_TEST = _HOME + 'zx/test.txt'
