# -*- coding:utf-8 -*-
# Author: hankcs
# Date: 2019-12-05 23:05
from hanlp.components.taggers.cnn_tagger_tf import CNNTaggerTF
from hanlp.components.taggers.rnn_tagger_tf import RNNTaggerTF


class CNNPartOfSpeechTaggerTF(CNNTaggerTF):
    pass


class RNNPartOfSpeechTaggerTF(RNNTaggerTF):
    pass
