# -*- coding:utf-8 -*-
# Author: hankcs
# Date: 2020-12-22 13:22
from hanlp_common.constant import HANLP_URL

UD_CTB_EOS_MUL = HANLP_URL + 'eos/eos_ud_ctb_mul_20201222_133543.zip'
'EOS model (:cite:`Schweter:Ahmed:2019`) trained on concatenated UD2.3 and CTB9.'

# Will be filled up during runtime
ALL = {}
